@@ -22,12 +22,12 @@
 #include "couchdb-document-contact.h"
 #include "utils.h"
 
-CouchDBDocument *
-couchdb_document_contact_new (CouchDB *couchdb)
+CouchdbDocument *
+couchdb_document_contact_new (CouchdbSession *couchdb)
 {
-	CouchDBDocument *document;
+	CouchdbDocument *document;
 
-	g_return_val_if_fail (COUCHDB_IS (couchdb), NULL);
+	g_return_val_if_fail (COUCHDB_IS_SESSION (couchdb), NULL);
 
 	document = couchdb_document_new (couchdb);
 	if (document)
@@ -37,7 +37,7 @@ couchdb_document_contact_new (CouchDB *couchdb)
 }
 
 gboolean
-couchdb_document_is_contact (CouchDBDocument *document)
+couchdb_document_is_contact (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), FALSE);
 
@@ -46,7 +46,7 @@ couchdb_document_is_contact (CouchDBDocument *document)
 }
 
 const char *
-couchdb_document_contact_get_first_name (CouchDBDocument *document)
+couchdb_document_contact_get_first_name (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -55,7 +55,7 @@ couchdb_document_contact_get_first_name (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_first_name (CouchDBDocument *document, const char *first_name)
+couchdb_document_contact_set_first_name (CouchdbDocument *document, const char *first_name)
 {
 	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -65,7 +65,7 @@ couchdb_document_contact_set_first_name (CouchDBDocument *document, const char *
 }
 
 const char *
-couchdb_document_contact_get_last_name (CouchDBDocument *document)
+couchdb_document_contact_get_last_name (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -74,7 +74,7 @@ couchdb_document_contact_get_last_name (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_last_name (CouchDBDocument *document, const char *last_name)
+couchdb_document_contact_set_last_name (CouchdbDocument *document, const char *last_name)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -84,7 +84,7 @@ couchdb_document_contact_set_last_name (CouchDBDocument *document, const char *l
 }
 
 const char *
-couchdb_document_contact_get_nick_name (CouchDBDocument *document)
+couchdb_document_contact_get_nick_name (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -93,7 +93,7 @@ couchdb_document_contact_get_nick_name (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_nick_name (CouchDBDocument *document, const char *nick_name)
+couchdb_document_contact_set_nick_name (CouchdbDocument *document, const char *nick_name)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -103,7 +103,7 @@ couchdb_document_contact_set_nick_name (CouchDBDocument *document, const char *n
 }
 
 const char *
-couchdb_document_contact_get_spouse_name (CouchDBDocument *document)
+couchdb_document_contact_get_spouse_name (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -112,7 +112,7 @@ couchdb_document_contact_get_spouse_name (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_spouse_name (CouchDBDocument *document, const char *spouse_name)
+couchdb_document_contact_set_spouse_name (CouchdbDocument *document, const char *spouse_name)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -122,7 +122,7 @@ couchdb_document_contact_set_spouse_name (CouchDBDocument *document, const char
 }
 
 const char *
-couchdb_document_contact_get_birth_date (CouchDBDocument *document)
+couchdb_document_contact_get_birth_date (CouchdbDocument *document)
 {
 	JsonObject *object;
 
@@ -133,7 +133,7 @@ couchdb_document_contact_get_birth_date (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_birth_date (CouchDBDocument *document, const char *birth_date)
+couchdb_document_contact_set_birth_date (CouchdbDocument *document, const char *birth_date)
 {
 	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -143,7 +143,7 @@ couchdb_document_contact_set_birth_date (CouchDBDocument *document, const char *
 }
 
 const char *
-couchdb_document_contact_get_wedding_date (CouchDBDocument *document)
+couchdb_document_contact_get_wedding_date (CouchdbDocument *document)
 {
 	JsonObject *object;
 
@@ -154,7 +154,7 @@ couchdb_document_contact_get_wedding_date (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_wedding_date (CouchDBDocument *document, const char *wedding_date)
+couchdb_document_contact_set_wedding_date (CouchdbDocument *document, const char *wedding_date)
 {
 	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -164,7 +164,7 @@ couchdb_document_contact_set_wedding_date (CouchDBDocument *document, const char
 }
 
 const char *
-couchdb_document_contact_get_company (CouchDBDocument *document)
+couchdb_document_contact_get_company (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -173,7 +173,7 @@ couchdb_document_contact_get_company (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_company (CouchDBDocument *document, const char *company)
+couchdb_document_contact_set_company (CouchdbDocument *document, const char *company)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -183,7 +183,7 @@ couchdb_document_contact_set_company (CouchDBDocument *document, const char *com
 }
 
 const char *
-couchdb_document_contact_get_department (CouchDBDocument *document)
+couchdb_document_contact_get_department (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -192,7 +192,7 @@ couchdb_document_contact_get_department (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_department (CouchDBDocument *document, const char *department)
+couchdb_document_contact_set_department (CouchdbDocument *document, const char *department)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -202,7 +202,7 @@ couchdb_document_contact_set_department (CouchDBDocument *document, const char *
 }
 
 const char *
-couchdb_document_contact_get_title (CouchDBDocument *document)
+couchdb_document_contact_get_title (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -211,7 +211,7 @@ couchdb_document_contact_get_title (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_title (CouchDBDocument *document, const char *title)
+couchdb_document_contact_set_title (CouchdbDocument *document, const char *title)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -221,7 +221,7 @@ couchdb_document_contact_set_title (CouchDBDocument *document, const char *title
 }
 
 const char *
-couchdb_document_contact_get_job_title (CouchDBDocument *document)
+couchdb_document_contact_get_job_title (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -230,7 +230,7 @@ couchdb_document_contact_get_job_title (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_job_title (CouchDBDocument *document, const char *job_title)
+couchdb_document_contact_set_job_title (CouchdbDocument *document, const char *job_title)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -240,7 +240,7 @@ couchdb_document_contact_set_job_title (CouchDBDocument *document, const char *j
 }
 
 const char *
-couchdb_document_contact_get_manager_name (CouchDBDocument *document)
+couchdb_document_contact_get_manager_name (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -249,7 +249,7 @@ couchdb_document_contact_get_manager_name (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_manager_name (CouchDBDocument *document, const char *manager_name)
+couchdb_document_contact_set_manager_name (CouchdbDocument *document, const char *manager_name)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -259,7 +259,7 @@ couchdb_document_contact_set_manager_name (CouchDBDocument *document, const char
 }
 
 const char *
-couchdb_document_contact_get_assistant_name (CouchDBDocument *document)
+couchdb_document_contact_get_assistant_name (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -268,7 +268,7 @@ couchdb_document_contact_get_assistant_name (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_assistant_name (CouchDBDocument *document, const char *assistant_name)
+couchdb_document_contact_set_assistant_name (CouchdbDocument *document, const char *assistant_name)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -278,7 +278,7 @@ couchdb_document_contact_set_assistant_name (CouchDBDocument *document, const ch
 }
 
 const char *
-couchdb_document_contact_get_office (CouchDBDocument *document)
+couchdb_document_contact_get_office (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -287,7 +287,7 @@ couchdb_document_contact_get_office (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_office (CouchDBDocument *document, const char *office)
+couchdb_document_contact_set_office (CouchdbDocument *document, const char *office)
 {
       	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -305,7 +305,7 @@ foreach_object_cb (JsonObject *object,
 	GSList **list = (GSList **) user_data;
 
 	if (json_node_get_node_type (member_node) == JSON_NODE_OBJECT) {
-		CouchDBStructField *sf;
+		CouchdbStructField *sf;
 
 		sf = couchdb_struct_field_new_from_json_object (
 			json_object_ref (json_node_get_object (member_node)));
@@ -316,19 +316,19 @@ foreach_object_cb (JsonObject *object,
 
 /**
  * couchdb_document_contact_get_email_addresses:
- * @document: A #CouchDBDocument object representing a contact
+ * @document: A #CouchdbDocument object representing a contact
  *
  * Retrieve a list of email addresses from the specified contact document.
- * Email addresses are returned in a GSList of #CouchDBStructField objects,
+ * Email addresses are returned in a GSList of #CouchdbStructField objects,
  * which can be manipulated with the couchdb_document_contact_email_* functions
  * and freed with:
  *     g_slist_foreach (list, (GFunc) couchdb_struct_field_unref, NULL);
  *     g_slist_free (list);
  *
- * Return value: a #GSList of #CouchDBStructField objects.
+ * Return value: a #GSList of #CouchdbStructField objects.
  */
 GSList *
-couchdb_document_contact_get_email_addresses (CouchDBDocument *document)
+couchdb_document_contact_get_email_addresses (CouchdbDocument *document)
 {
 	GSList *list = NULL;
 	JsonObject *addresses_json;
@@ -337,7 +337,7 @@ couchdb_document_contact_get_email_addresses (CouchDBDocument *document)
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
 
 	addresses_json = json_object_get_object_member (
-		json_node_get_object (document->root_node), "email_addresses");;
+		couchdb_document_get_json_object (document), "email_addresses");;
 	if (addresses_json) {
 		json_object_foreach_member (addresses_json,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -348,7 +348,7 @@ couchdb_document_contact_get_email_addresses (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_email_addresses (CouchDBDocument *document, GSList *list)
+couchdb_document_contact_set_email_addresses (CouchdbDocument *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *addresses_json;
@@ -358,7 +358,7 @@ couchdb_document_contact_set_email_addresses (CouchDBDocument *document, GSList
 	addresses_json = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
 		const gchar *address_str;
-		CouchDBStructField *sf = (CouchDBStructField *) l->data;
+		CouchdbStructField *sf = (CouchdbStructField *) l->data;
 
 		address_str = couchdb_document_contact_email_get_address (sf);
 		if (address_str) {
@@ -375,11 +375,11 @@ couchdb_document_contact_set_email_addresses (CouchDBDocument *document, GSList
 		}
 	}
 
-	json_object_set_object_member (json_node_get_object (document->root_node), "email_addresses", addresses_json);
+	json_object_set_object_member (couchdb_document_get_json_object (document), "email_addresses", addresses_json);
 }
 
 GSList *
-couchdb_document_contact_get_phone_numbers (CouchDBDocument *document)
+couchdb_document_contact_get_phone_numbers (CouchdbDocument *document)
 {
 	GSList *list = NULL;
 	JsonObject *phone_numbers;
@@ -388,7 +388,7 @@ couchdb_document_contact_get_phone_numbers (CouchDBDocument *document)
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
 
 	phone_numbers = json_object_get_object_member (
-		json_node_get_object (document->root_node), "phone_numbers");
+		couchdb_document_get_json_object (document), "phone_numbers");
 	if (phone_numbers) {
 		json_object_foreach_member (phone_numbers,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -399,7 +399,7 @@ couchdb_document_contact_get_phone_numbers (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_phone_numbers (CouchDBDocument *document, GSList *list)
+couchdb_document_contact_set_phone_numbers (CouchdbDocument *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *phone_numbers;
@@ -409,7 +409,7 @@ couchdb_document_contact_set_phone_numbers (CouchDBDocument *document, GSList *l
 	phone_numbers = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
 		const gchar *number_str;
-		CouchDBStructField *sf = (CouchDBStructField *) l->data;
+		CouchdbStructField *sf = (CouchdbStructField *) l->data;
 
 		number_str = couchdb_document_contact_phone_get_number (sf);
 		if (number_str) {
@@ -428,11 +428,11 @@ couchdb_document_contact_set_phone_numbers (CouchDBDocument *document, GSList *l
 		}
 	}
 
-	json_object_set_object_member (json_node_get_object (document->root_node), "phone_numbers", phone_numbers);
+	json_object_set_object_member (couchdb_document_get_json_object (document), "phone_numbers", phone_numbers);
 }
 
 GSList *
-couchdb_document_contact_get_addresses (CouchDBDocument *document)
+couchdb_document_contact_get_addresses (CouchdbDocument *document)
 {
 	GSList *list = NULL;
 	JsonObject *addresses;
@@ -441,7 +441,7 @@ couchdb_document_contact_get_addresses (CouchDBDocument *document)
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
 
 	addresses = json_object_get_object_member (
-		json_node_get_object (document->root_node), "addresses");
+		couchdb_document_get_json_object (document), "addresses");
 	if (addresses) {
 		json_object_foreach_member (addresses,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -452,7 +452,7 @@ couchdb_document_contact_get_addresses (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_addresses (CouchDBDocument *document, GSList *list)
+couchdb_document_contact_set_addresses (CouchdbDocument *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *addresses;
@@ -462,7 +462,7 @@ couchdb_document_contact_set_addresses (CouchDBDocument *document, GSList *list)
 	addresses = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
 		const gchar *street_str;
-		CouchDBStructField *sf = (CouchDBStructField *) l->data;
+		CouchdbStructField *sf = (CouchdbStructField *) l->data;
 
 		street_str = couchdb_document_contact_address_get_street (sf);
 		if (street_str) {
@@ -489,11 +489,11 @@ couchdb_document_contact_set_addresses (CouchDBDocument *document, GSList *list)
 		}
 	}
 
-	json_object_set_object_member (json_node_get_object (document->root_node), "addresses", addresses);
+	json_object_set_object_member (couchdb_document_get_json_object (document), "addresses", addresses);
 }
 
 GSList *
-couchdb_document_contact_get_im_addresses (CouchDBDocument *document)
+couchdb_document_contact_get_im_addresses (CouchdbDocument *document)
 {
 	GSList *list = NULL;
 	JsonObject *im_addresses;
@@ -502,7 +502,7 @@ couchdb_document_contact_get_im_addresses (CouchDBDocument *document)
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
 
 	im_addresses = json_object_get_object_member (
-		json_node_get_object (document->root_node), "im_addresses");
+		couchdb_document_get_json_object (document), "im_addresses");
 	if (im_addresses != NULL) {
 		json_object_foreach_member (im_addresses,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -513,7 +513,7 @@ couchdb_document_contact_get_im_addresses (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_im_addresses (CouchDBDocument *document, GSList *list)
+couchdb_document_contact_set_im_addresses (CouchdbDocument *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *im_addresses_json;
@@ -523,7 +523,7 @@ couchdb_document_contact_set_im_addresses (CouchDBDocument *document, GSList *li
 	im_addresses_json = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
 		const gchar *address_str;
-		CouchDBStructField *sf = (CouchDBStructField *) l->data;
+		CouchdbStructField *sf = (CouchdbStructField *) l->data;
 
 		address_str = couchdb_document_contact_im_get_address (sf);
 		if (address_str != NULL) {
@@ -542,11 +542,11 @@ couchdb_document_contact_set_im_addresses (CouchDBDocument *document, GSList *li
 		}
 	}
 
-	json_object_set_object_member (json_node_get_object (document->root_node), "im_addresses", im_addresses_json);
+	json_object_set_object_member (couchdb_document_get_json_object (document), "im_addresses", im_addresses_json);
 }
 
 GSList *
-couchdb_document_contact_get_urls (CouchDBDocument *document)
+couchdb_document_contact_get_urls (CouchdbDocument *document)
 {
 	GSList *list = NULL;
 	JsonObject *urls;
@@ -555,7 +555,7 @@ couchdb_document_contact_get_urls (CouchDBDocument *document)
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
 
 	urls = json_object_get_object_member (
-		json_node_get_object (document->root_node), "urls");
+		couchdb_document_get_json_object (document), "urls");
 	if (urls) {
 		json_object_foreach_member (urls,
 					    (JsonObjectForeach) foreach_object_cb,
@@ -566,7 +566,7 @@ couchdb_document_contact_get_urls (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_urls (CouchDBDocument *document, GSList *list)
+couchdb_document_contact_set_urls (CouchdbDocument *document, GSList *list)
 {
 	GSList *l;
 	JsonObject *urls_json;
@@ -576,7 +576,7 @@ couchdb_document_contact_set_urls (CouchDBDocument *document, GSList *list)
 	urls_json = json_object_new ();
 	for (l = list; l != NULL; l = l->next) {
 		const gchar *address_str;
-		CouchDBStructField *sf = (CouchDBStructField *) l->data;
+		CouchdbStructField *sf = (CouchdbStructField *) l->data;
 
 		address_str = couchdb_document_contact_url_get_address (sf);
 		if (address_str) {
@@ -593,11 +593,11 @@ couchdb_document_contact_set_urls (CouchDBDocument *document, GSList *list)
 		}
 	}
 
-	json_object_set_object_member (json_node_get_object (document->root_node), "urls", urls_json);
+	json_object_set_object_member (couchdb_document_get_json_object (document), "urls", urls_json);
 }
 
 const char *
-couchdb_document_contact_get_notes (CouchDBDocument *document)
+couchdb_document_contact_get_notes (CouchdbDocument *document)
 {
 	g_return_val_if_fail (COUCHDB_IS_DOCUMENT (document), NULL);
 	g_return_val_if_fail (couchdb_document_is_contact (document), NULL);
@@ -606,7 +606,7 @@ couchdb_document_contact_get_notes (CouchDBDocument *document)
 }
 
 void
-couchdb_document_contact_set_notes (CouchDBDocument *document, const char *notes)
+couchdb_document_contact_set_notes (CouchdbDocument *document, const char *notes)
 {
 	g_return_if_fail (COUCHDB_IS_DOCUMENT (document));
 	g_return_if_fail (couchdb_document_is_contact (document));
@@ -615,10 +615,10 @@ couchdb_document_contact_set_notes (CouchDBDocument *document, const char *notes
 	couchdb_document_set_string_field (document, "notes", notes);
 }
 
-CouchDBStructField *
+CouchdbStructField *
 couchdb_document_contact_email_new (const char *uuid, const char *address, const char *description)
 {
-	CouchDBStructField *sf;
+	CouchdbStructField *sf;
 
 	sf = couchdb_struct_field_new_from_json_object (json_object_new ());
 	if (uuid != NULL)
@@ -638,7 +638,7 @@ couchdb_document_contact_email_new (const char *uuid, const char *address, const
 }
 
 const char *
-couchdb_document_contact_email_get_address (CouchDBStructField *sf)
+couchdb_document_contact_email_get_address (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -646,7 +646,7 @@ couchdb_document_contact_email_get_address (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_email_set_address (CouchDBStructField *sf, const char *email)
+couchdb_document_contact_email_set_address (CouchdbStructField *sf, const char *email)
 {
 	g_return_if_fail (sf != NULL);
 	g_return_if_fail (email != NULL);
@@ -655,7 +655,7 @@ couchdb_document_contact_email_set_address (CouchDBStructField *sf, const char *
 }
 
 const char *
-couchdb_document_contact_email_get_description (CouchDBStructField *sf)
+couchdb_document_contact_email_get_description (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -663,17 +663,17 @@ couchdb_document_contact_email_get_description (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_email_set_description (CouchDBStructField *sf, const char *description)
+couchdb_document_contact_email_set_description (CouchdbStructField *sf, const char *description)
 {
 	g_return_if_fail (sf != NULL);
 
 	couchdb_struct_field_set_string_field (sf, "description", description);
 }
 
-CouchDBStructField *
+CouchdbStructField *
 couchdb_document_contact_phone_new (const char *uuid, const char *number, const char *description, gint priority)
 {
-	CouchDBStructField *sf;
+	CouchdbStructField *sf;
 
 	sf = couchdb_struct_field_new_from_json_object (json_object_new ());
 	if (uuid != NULL)
@@ -694,7 +694,7 @@ couchdb_document_contact_phone_new (const char *uuid, const char *number, const
 }
 
 gint
-couchdb_document_contact_phone_get_priority (CouchDBStructField *sf)
+couchdb_document_contact_phone_get_priority (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, 0);
 
@@ -702,7 +702,7 @@ couchdb_document_contact_phone_get_priority (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_phone_set_priority (CouchDBStructField *sf, gint priority)
+couchdb_document_contact_phone_set_priority (CouchdbStructField *sf, gint priority)
 {
 	g_return_if_fail (sf != NULL);
 
@@ -710,7 +710,7 @@ couchdb_document_contact_phone_set_priority (CouchDBStructField *sf, gint priori
 }
 
 const char *
-couchdb_document_contact_phone_get_number (CouchDBStructField *sf)
+couchdb_document_contact_phone_get_number (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -718,7 +718,7 @@ couchdb_document_contact_phone_get_number (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_phone_set_number (CouchDBStructField *sf, const char *number)
+couchdb_document_contact_phone_set_number (CouchdbStructField *sf, const char *number)
 {
 	g_return_if_fail (sf != NULL);
 	g_return_if_fail (number != NULL);
@@ -727,7 +727,7 @@ couchdb_document_contact_phone_set_number (CouchDBStructField *sf, const char *n
 }
 
 const char *
-couchdb_document_contact_phone_get_description (CouchDBStructField *sf)
+couchdb_document_contact_phone_get_description (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -735,14 +735,14 @@ couchdb_document_contact_phone_get_description (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_phone_set_description (CouchDBStructField *sf, const char *description)
+couchdb_document_contact_phone_set_description (CouchdbStructField *sf, const char *description)
 {
 	g_return_if_fail (sf != NULL);
 
 	couchdb_struct_field_set_string_field (sf, "description", description);
 }
 
-CouchDBStructField *
+CouchdbStructField *
 couchdb_document_contact_address_new (const char *uuid,
 				      const char *street,
 				      const char *city,
@@ -752,7 +752,7 @@ couchdb_document_contact_address_new (const char *uuid,
 				      const char *pobox,
 				      const char *description)
 {
-	CouchDBStructField *sf;
+	CouchdbStructField *sf;
 
 	sf = couchdb_struct_field_new_from_json_object (json_object_new ());
 	if (uuid != NULL)
@@ -782,7 +782,7 @@ couchdb_document_contact_address_new (const char *uuid,
 }
 
 const char *
-couchdb_document_contact_address_get_street (CouchDBStructField *sf)
+couchdb_document_contact_address_get_street (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -790,7 +790,7 @@ couchdb_document_contact_address_get_street (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_address_set_street (CouchDBStructField *sf, const char *street)
+couchdb_document_contact_address_set_street (CouchdbStructField *sf, const char *street)
 {
 	g_return_if_fail (sf != NULL);
 
@@ -798,7 +798,7 @@ couchdb_document_contact_address_set_street (CouchDBStructField *sf, const char
 }
 
 const char *
-couchdb_document_contact_address_get_city (CouchDBStructField *sf)
+couchdb_document_contact_address_get_city (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -806,7 +806,7 @@ couchdb_document_contact_address_get_city (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_address_set_city (CouchDBStructField *sf, const char *city)
+couchdb_document_contact_address_set_city (CouchdbStructField *sf, const char *city)
 {
 	g_return_if_fail (sf != NULL);
 
@@ -814,7 +814,7 @@ couchdb_document_contact_address_set_city (CouchDBStructField *sf, const char *c
 }
 
 const char *
-couchdb_document_contact_address_get_state (CouchDBStructField *sf)
+couchdb_document_contact_address_get_state (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -822,7 +822,7 @@ couchdb_document_contact_address_get_state (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_address_set_state (CouchDBStructField *sf, const char *state)
+couchdb_document_contact_address_set_state (CouchdbStructField *sf, const char *state)
 {
 	g_return_if_fail (sf != NULL);
 
@@ -830,7 +830,7 @@ couchdb_document_contact_address_set_state (CouchDBStructField *sf, const char *
 }
 
 const char *
-couchdb_document_contact_address_get_country (CouchDBStructField *sf)
+couchdb_document_contact_address_get_country (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -838,7 +838,7 @@ couchdb_document_contact_address_get_country (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_address_set_country (CouchDBStructField *sf, const char *country)
+couchdb_document_contact_address_set_country (CouchdbStructField *sf, const char *country)
 {
 	g_return_if_fail (sf != NULL);
 
@@ -846,7 +846,7 @@ couchdb_document_contact_address_set_country (CouchDBStructField *sf, const char
 }
 
 const char *
-couchdb_document_contact_address_get_postalcode (CouchDBStructField *sf)
+couchdb_document_contact_address_get_postalcode (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -854,7 +854,7 @@ couchdb_document_contact_address_get_postalcode (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_address_set_postalcode (CouchDBStructField *sf, const char *postalcode)
+couchdb_document_contact_address_set_postalcode (CouchdbStructField *sf, const char *postalcode)
 {
 	g_return_if_fail (sf != NULL);
 
@@ -862,7 +862,7 @@ couchdb_document_contact_address_set_postalcode (CouchDBStructField *sf, const c
 }
 
 const char *
-couchdb_document_contact_address_get_pobox (CouchDBStructField *sf)
+couchdb_document_contact_address_get_pobox (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -870,7 +870,7 @@ couchdb_document_contact_address_get_pobox (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_address_set_pobox (CouchDBStructField *sf, const char *pobox)
+couchdb_document_contact_address_set_pobox (CouchdbStructField *sf, const char *pobox)
 {
 	g_return_if_fail (sf != NULL);
 
@@ -878,7 +878,7 @@ couchdb_document_contact_address_set_pobox (CouchDBStructField *sf, const char *
 }
 
 const char *
-couchdb_document_contact_address_get_description (CouchDBStructField *sf)
+couchdb_document_contact_address_get_description (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -886,20 +886,20 @@ couchdb_document_contact_address_get_description (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_address_set_description (CouchDBStructField *sf, const char *description)
+couchdb_document_contact_address_set_description (CouchdbStructField *sf, const char *description)
 {
 	g_return_if_fail (sf != NULL);
 
 	couchdb_struct_field_set_string_field (sf, "description", description);
 }
 
-CouchDBStructField *
+CouchdbStructField *
 couchdb_document_contact_im_new (const char *uuid,
 				 const char *address,
 				 const char *description,
 				 const char *protocol)
 {
-	CouchDBStructField *sf;
+	CouchdbStructField *sf;
 
 	sf = couchdb_struct_field_new_from_json_object (json_object_new ());
 	if (uuid != NULL)
@@ -921,7 +921,7 @@ couchdb_document_contact_im_new (const char *uuid,
 }
 
 const char *
-couchdb_document_contact_im_get_address (CouchDBStructField *sf)
+couchdb_document_contact_im_get_address (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -929,7 +929,7 @@ couchdb_document_contact_im_get_address (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_im_set_address (CouchDBStructField *sf, const char *address)
+couchdb_document_contact_im_set_address (CouchdbStructField *sf, const char *address)
 {
 	g_return_if_fail (sf != NULL);
 	g_return_if_fail (address != NULL);
@@ -938,7 +938,7 @@ couchdb_document_contact_im_set_address (CouchDBStructField *sf, const char *add
 }
 
 const char *
-couchdb_document_contact_im_get_description (CouchDBStructField *sf)
+couchdb_document_contact_im_get_description (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -946,7 +946,7 @@ couchdb_document_contact_im_get_description (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_im_set_description (CouchDBStructField *sf, const char *description)
+couchdb_document_contact_im_set_description (CouchdbStructField *sf, const char *description)
 {
 	g_return_if_fail (sf != NULL);
 	g_return_if_fail (description != NULL);
@@ -955,7 +955,7 @@ couchdb_document_contact_im_set_description (CouchDBStructField *sf, const char
 }
 
 const char *
-couchdb_document_contact_im_get_protocol (CouchDBStructField *sf)
+couchdb_document_contact_im_get_protocol (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -963,7 +963,7 @@ couchdb_document_contact_im_get_protocol (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_im_set_protocol (CouchDBStructField *sf, const char *protocol)
+couchdb_document_contact_im_set_protocol (CouchdbStructField *sf, const char *protocol)
 {
 	g_return_if_fail (sf != NULL);
 	g_return_if_fail (protocol != NULL);
@@ -971,10 +971,10 @@ couchdb_document_contact_im_set_protocol (CouchDBStructField *sf, const char *pr
 	couchdb_struct_field_set_string_field (sf, "protocol", protocol);
 }
 
-CouchDBStructField *
+CouchdbStructField *
 couchdb_document_contact_url_new (const char *uuid, const char *address, const char *description)
 {
-	CouchDBStructField *sf;
+	CouchdbStructField *sf;
 
 	sf = couchdb_struct_field_new_from_json_object (json_object_new ());
 	if (uuid != NULL)
@@ -994,7 +994,7 @@ couchdb_document_contact_url_new (const char *uuid, const char *address, const c
 }
 
 const char *
-couchdb_document_contact_url_get_address (CouchDBStructField *sf)
+couchdb_document_contact_url_get_address (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -1002,7 +1002,7 @@ couchdb_document_contact_url_get_address (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_url_set_address (CouchDBStructField *sf, const char *url)
+couchdb_document_contact_url_set_address (CouchdbStructField *sf, const char *url)
 {
 	g_return_if_fail (sf != NULL);
 	g_return_if_fail (url != NULL);
@@ -1011,7 +1011,7 @@ couchdb_document_contact_url_set_address (CouchDBStructField *sf, const char *ur
 }
 
 const char *
-couchdb_document_contact_url_get_description (CouchDBStructField *sf)
+couchdb_document_contact_url_get_description (CouchdbStructField *sf)
 {
 	g_return_val_if_fail (sf != NULL, NULL);
 
@@ -1019,7 +1019,7 @@ couchdb_document_contact_url_get_description (CouchDBStructField *sf)
 }
 
 void
-couchdb_document_contact_url_set_description (CouchDBStructField *sf, const char *description)
+couchdb_document_contact_url_set_description (CouchdbStructField *sf, const char *description)
 {
 	g_return_if_fail (sf != NULL);
 
